@@ -234,9 +234,8 @@ sub _pad_bytes_for_asn1 {
     my ($self, $bytes) = @_;
 
     my $curve_hr = $self->_curve();
-    my $nbytes = length $curve_hr->{'n'}->as_bytes();
+    my $nbytes = length $curve_hr->{'p'}->as_bytes();
 
-#print "pad: $nbytes / " . length($bytes) . $/;
     substr( $bytes, 0, 0 ) = ("\0" x ($nbytes - length $bytes));
 
     return $bytes;
@@ -262,6 +261,15 @@ sub _explicit_curve_parameters {
         $str = $self->_pad_bytes_for_asn1($str);
     }
 
+    my %curve = (
+        a => $curve_hr->{'a'}->as_bytes(),
+        b => $curve_hr->{'b'}->as_bytes(),
+    );
+
+    if ($curve_hr->{'seed'}) {
+        $curve{'seed'} = $curve_hr->{'seed'}->as_bytes();
+    }
+
     return {
         ecParameters => {
             version => 1,
@@ -271,10 +279,7 @@ sub _explicit_curve_parameters {
                     'prime-field' => $curve_hr->{'p'},
                 },
             },
-            curve => {
-                a => $curve_hr->{'a'}->as_bytes(),
-                b => $curve_hr->{'b'}->as_bytes(),
-            },
+            curve => \%curve,
             base => "\x{04}$gx$gy",
             order => $curve_hr->{'n'},
             cofactor => $curve_hr->{'h'},
@@ -291,6 +296,10 @@ sub __to_der {
 
     my ($pub_x, $pub_y) = Crypt::Perl::ECDSA::Utils::split_G_or_public( $self->{'public'}->as_bytes() );
 
+    for my $str ( $pub_x, $pub_y ) {
+        $str = $self->_pad_bytes_for_asn1($str);
+    }
+
     local $data_hr->{'publicKey'} = "\x04$pub_x$pub_y";
 
     Module::Load::load('Crypt::Perl::ASN1');
